Module uim.model
================
Package for the UIM model.
This package contains the data model for the UIM.

Sub-modules
-----------
* uim.model.base
* uim.model.helpers
* uim.model.ink
* uim.model.inkdata
* uim.model.inkinput
* uim.model.semantics